@@ -1,8 +1,8 @@
 use super::*;
 
-pub fn render_plots<XI: IntoIterator, YI: IntoIterator>(
+pub fn render_plots<XI: IntoIterator, YI: IntoIterator, PF: PlotFmt<X = XI::Item, Y = YI::Item>>(
     writer: impl std::fmt::Write,
-    plotter: &mut Plotter<XI, YI>,
+    plotter: &mut Plotter<XI, YI, PF>,
 ) -> std::fmt::Result
 where
     XI::Item: PlotNum,
